<?php
/**
*
* search_ignore_words [Catalan]
*
* @package language
* @version $Id: search_ignore_words.php,v 1.2 2006/10/08 11:21:39 acydburn Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$words = array(
	'a',
	'això',
	'al',
	'algú',
	'algun',
	'alguna',
	'algunes',
	'alguns',
	'altra',
	'altre',
	'altres',
	'allà',
	'allò',
	'amb',
	'aquell',
	'aquella',
	'aquelles',
	'aquells',
	'aquest',
	'aquesta',
	'aquestes',
	'aquests',
	'aquí',
	'ara',
	'arreu',
	'bé',
	'ben',
	'bo',
	'bon',
	'cada',
	'cap',
	'cert',
	'com',
	'contra',
	'darrere',
	'de',
	'del',
	'des',
	'després',
	'devers',
	'doncs',
	'durant',
	'el',
	'els',
	'ell',
	'ella',
	'elles',
	'ells',
	'em',
	'en',
	'enlloc',
	'ens',
	'entre',
	'envers',
	'es',
	'et',
	'etc',
	'fins',
	'gens',
	'ha',
	'han',
	'has',
	'he',
	'hem',
	'heu',
	'hi',
	'i',
	'jo',
	'la',
	'les',
	'li',
	'llavors',
	'llur',
	'llurs',
	'mai',
	'mal',
	'malgrat',
	'menys',
	'més',
	'meu',
	'meus',
	'meva',
	'meves',
	'mi',
	'mica',
	'molt',
	'moltes',
	'molts',
	'na',
	'ni',
	'ningú',
	'no',
	'només',
	'nosaltres',
	'nostra',
	'nostre',
	'nostres',
	'o',
	'per',
	'però',
	'perquè',
	'poc',
	'potser',
	'pro',
	'qual',
	'quasi',
	'que',
	'què',
	'res',
	'sa',
	'segons',
	'sempre',
	'sense',
	'ses',
	'seu',
	'seus',
	'seva',
	'seves',
	'si',
	'sí',
	'sobre',
	'sos',
	'sota',
	'sovint',
	'tal',
	'també',
	'tan',
	'tanmateix',
	'teu',
	'teus',
	'teva',
	'teves',
	'tot',
	'tota',
	'totes',
	'tothom',
	'tots',
	'tu',
	'ultra',
	'un',
	'una',
	'unes',
	'uns',
	'us',
	'va',
	'vaig',
	'vam',
	'van',
	'vàrem',
	'vàreu',
	'vas',
	'vau',
	'vers',
	'vosaltres',
	'vostra',
	'vostre',
	'vostres',
);

?>