<?php
/**
*
* search_synonyms [Catalan]
*
* @package language
* @version $Id: search_synonyms.php,v 1.2 2007/04/16 17:14:18 shs Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$synonyms = array(
	'pero'			=> 'però',
);
?>